@@ -7,7 +7,7 @@ use strict;
 use warnings;
 
 use Moose::Exporter;
-use MooseX::App::Exporter qw(app_base app_fuzzy option parameter command_short_description command_long_description command_usage);
+use MooseX::App::Exporter qw(app_base app_fuzzy app_strict option parameter command_short_description command_long_description command_usage);
 use MooseX::App::Meta::Role::Attribute::Option;
 use MooseX::App::Message::Envelope;
 use Scalar::Util qw(blessed);
@@ -15,7 +15,7 @@ use Scalar::Util qw(blessed);
 our $VERSION = '1.15';
 
 my ($IMPORT,$UNIMPORT,$INIT_META) = Moose::Exporter->build_import_methods(
-    with_meta           => [ qw(app_base app_fuzzy option parameter command_short_description command_long_description command_usage) ],
+    with_meta           => [ qw(app_base app_fuzzy app_strict option parameter command_short_description command_long_description command_usage) ],
     also                => [ 'Moose' ],
     as_is               => [ 'new_with_options' ],
     install             => [ 'unimport', 'init_meta' ],
@@ -69,7 +69,7 @@ sub new_with_options {
     } elsif (scalar @args % 2 == 0) {
         %args = @args;
     } else {
-        Moose->throw_error('new_with_command got inavlid extra arguments');
+        Moose->throw_error('new_with_command got invalid extra arguments');
     }
     
     # Get ARGV
@@ -162,4 +162,4 @@ MooseX::App command line application.
 
 See L<MooseX::Getopt> and L<MooX::Options> for alternatives
 
-=cut
\ No newline at end of file
+=cut
